@@ -184,30 +184,24 @@ async def _ensure_valid_jwt(psk_token: str, sovereign_url: str) -> str:
     return jwt
 
 
-async def verify_token_with_server(token: str, base_url: str) -> bool:
+def verify_token_format(token: str) -> bool:
     """
-    Verify token with sovereign /verify endpoint.
+    Verify token format is valid (basic check, not server verification).
+    Actual token validation happens when we call /api/warden/mint.
 
     Args:
-        token: Auth token to verify (raw token, not base64 encoded)
-        base_url: Sovereign base URL
+        token: Auth token to verify
 
     Returns:
-        True if token is valid
+        True if token format is valid
 
     Raises:
-        RuntimeError: If token is invalid
+        RuntimeError: If token format is invalid
     """
-    async with httpx.AsyncClient(base_url=base_url, timeout=5.0) as client:
-        # Send raw token in JSON body (not base64 encoded)
-        response = await client.post("/verify", json={"token": token})
-        response.raise_for_status()
-
-        result = response.json()
-        if not result.get("valid"):
-            raise RuntimeError(f"Token invalid: {result.get('error', 'Invalid token')}")
-
-        return True
+    # PSK tokens are 64-character hex strings
+    if not token or len(token) < 32:
+        raise RuntimeError("Invalid token format")
+    return True
 
 
 async def health_check_all(base_url: str) -> dict:
